@@ -174,11 +174,11 @@ setGeneric(name = "twdtwRaster",
 #' nir = brick(system.file("lucc_MT/data/nir.tif", package="dtwSat"))
 #' mir = brick(system.file("lucc_MT/data/mir.tif", package="dtwSat"))
 #' doy = brick(system.file("lucc_MT/data/doy.tif", package="dtwSat"))
-#' rts = twdtwRaster(evi, ndvi, blue, red, nir, mir, timeline=timeline, doy=doy)
+#' rts = twdtwRaster(doy, evi, ndvi, blue, red, nir, mir, timeline = timeline)
 #' }
 #' @export
 setMethod(f = "twdtwRaster",  
-          definition = function(..., timeline, doy, layers, labels, levels, filepath){
+          definition = function(..., timeline, doy, layers, labels, levels){
               arg_names = names(list(...))
               not_named = setdiff(as.character(match.call(expand.dots=TRUE)), as.character(match.call(expand.dots=FALSE)))
               if(is.null(arg_names)){ 
@@ -188,6 +188,12 @@ setMethod(f = "twdtwRaster",
               }
               x = list(...)
               names(x) = c(arg_names)
+              if(missing(doy)){
+                if(any(arg_names %in% "doy")){
+                  doy = x[[which(arg_names %in% "doy")]]
+                  x = x[which(!(arg_names %in% "doy"))]
+                }
+              }
               I = which(sapply(x, is, "RasterBrick") | sapply(x, is, "RasterStack") | sapply(x, is, "RasterLayer"))
               if(length(I) < 1)
                 stop("there is no Raster* objects in the list of arguments")
@@ -195,11 +201,11 @@ setMethod(f = "twdtwRaster",
               timeseries = x[I]
               dotargs = x[-I]
               creat.twdtwRaster(timeseries=timeseries, timeline=as.Date(timeline), doy=doy,
-                                layers=layers, labels=labels, levels=levels, filepath=filepath, dotargs=dotargs)
+                                layers=layers, labels=labels, levels=levels, dotargs=dotargs)
           })
 
 
-creat.twdtwRaster = function(timeseries, timeline, doy, layers, labels, levels, filepath, dotargs){
+creat.twdtwRaster = function(timeseries, timeline, doy, layers, labels, levels, dotargs){
   
   # Check timeline 
   nl = sapply(c(timeseries), nlayers)
@@ -210,26 +216,26 @@ creat.twdtwRaster = function(timeseries, timeline, doy, layers, labels, levels,
   
   res = timeseries
   # Save a single file (complete time series) for each raster attribute 
-  if (!is.null(filepath)) {
-    dir.create(filepath, showWarnings = FALSE)
-    write(as.character(timeline), file = paste(filepath, "timeline", sep="/"))
-    aux = res
-    if(!is.null(doy))
-      aux = c(doy=doy, res)
-    res_brick = lapply(names(aux), function(i){
-      filename = paste(filepath, i, sep="/")
-      dotargs = c(x = aux[[i]], filename = filename, dotargs)
-      r = do.call(writeRaster, dotargs)
-      r
-    })
-    names(res_brick) = names(aux)
-    doy = NULL
-    res = res_brick
-    if(any(names(res)=="doy")){
-      res = res_brick[-1]
-      doy = res_brick[[1]]
-    }
-  }
+  # if (filepath != "") {
+  #   dir.create(filepath, showWarnings = FALSE)
+  #   write(as.character(timeline), file = paste(filepath, "timeline", sep="/"))
+  #   aux = res
+  #   if(!is.null(doy))
+  #     aux = c(doy=doy, res)
+  #   res_brick = lapply(names(aux), function(i){
+  #     filename = paste(filepath, i, sep="/")
+  #     dotargs = c(x = aux[[i]], filename = filename, dotargs)
+  #     r = do.call(writeRaster, dotargs)
+  #     r
+  #   })
+  #   names(res_brick) = names(aux)
+  #   doy = NULL
+  #   res = res_brick
+  #   if(any(names(res)=="doy")){
+  #     res = res_brick[-1]
+  #     doy = res_brick[[1]]
+  #   }
+  # }
   if(is.null(layers)) layers = names(res)
   if(is.null(doy)) 
     return(new("twdtwRaster", timeseries = res, timeline = timeline, layers = layers, labels = labels, levels=levels))
