@@ -13,7 +13,7 @@
 ###############################################################
 
 
-#' @useDynLib dtwSat computecost
+# @useDynLib dtwSat computecost
 .computecost = function(cm, step.matrix){
   
   cm = rbind(0, cm)
@@ -21,15 +21,14 @@
   m = ncol(cm)
   
   if(is.loaded("computecost", PACKAGE = "dtwSat", type = "Fortran")){
-    out = .Fortran("computecost", 
+    out = .Fortran(computecost, 
                    CM = matrix(as.double(cm), n, m),
                    DM = matrix(as.integer(0), n, m),
                    VM = matrix(as.integer(0), n, m),
                    SM = matrix(as.integer(step.matrix), nrow(step.matrix), ncol(step.matrix)),
                    N  = as.integer(n),
                    M  = as.integer(m),
-                   NS = as.integer(nrow(step.matrix)),
-                   PACKAGE="dtwSat")
+                   NS = as.integer(nrow(step.matrix)))
   } else {
     stop("Fortran computecost lib is not loaded")
   }
@@ -45,7 +44,7 @@
 }
 
 
-#' @useDynLib dtwSat tracepath
+# @useDynLib dtwSat tracepath
 .tracepath = function(dm, step.matrix, jmin){
 
     n = nrow(dm)
@@ -55,7 +54,7 @@
     
     if(is.loaded("tracepath", PACKAGE = "dtwSat", type = "Fortran")){
       aloc = length(jmin)*10*n
-      paths = .Fortran("tracepath", 
+      paths = .Fortran(tracepath, 
                        DM   = matrix(as.integer(dm), n, m),
                        SM   = matrix(as.integer(step.matrix), nrow(step.matrix), ncol(step.matrix)),
                        JMIN = as.vector(as.integer(jmin)),
@@ -66,8 +65,7 @@
                        M    = as.integer(m),
                        NS   = as.integer(nrow(step.matrix)),
                        NJ   = as.integer(length(jmin)),
-                       AL   = as.integer(aloc),
-                       PACKAGE="dtwSat")
+                       AL   = as.integer(aloc))
       
       res = lapply(seq_along(paths$POS)[-1], function(p){
         I = paths$POS[p]:((paths$POS[p-1])+1)
@@ -80,7 +78,7 @@
     res
 }
 
-#' @useDynLib dtwSat bestmatches
+# @useDynLib dtwSat bestmatches
 .bestmatches = function(x, m, n, levels, breaks, overlap, fill=9999){
   if(is.loaded("bestmatches", PACKAGE = "dtwSat", type = "Fortran")){
     if(length(x[[1]]$distance)<1){
@@ -88,7 +86,7 @@
                 XM = matrix(as.integer(c(as.numeric(x[[1]]$from), as.numeric(x[[1]]$to))), ncol = 2),
                 AM = matrix(as.double(fill), nrow = n, ncol = m), 
                 DM = as.double(x[[1]]$distance),
-                DP  = as.integer(as.numeric(breaks)),
+                DP = as.integer(as.numeric(breaks)),
                 X  = as.integer(match(x[[1]]$label, levels)),
                 IM = matrix(as.integer(0), nrow = n, ncol = 3),
                 A  = as.integer(x[[1]]$Alig.N),
@@ -97,7 +95,7 @@
                 L  = as.integer(length(levels)),
                 OV = as.double(overlap))
     } else {
-        res = try(.Fortran("bestmatches", 
+        res = try(.Fortran(bestmatches, 
                        XM = matrix(as.integer(c(as.numeric(x[[1]]$from), as.numeric(x[[1]]$to))), ncol = 2),
                        AM = matrix(as.double(fill), nrow = n, ncol = m), 
                        DM = as.double(x[[1]]$distance),
@@ -108,8 +106,7 @@
                        K  = as.integer(length(x)),
                        P  = as.integer(length(breaks)),
                        L  = as.integer(length(levels)),
-                       OV = as.double(overlap),
-                       PACKAGE="dtwSat")) 
+                       OV = as.double(overlap))) 
    }
   } else {
     stop("Fortran bestmatches lib is not loaded")
